#
# spec file for package gzdoom
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gzdoom
Version:        4.12.2
Release:        4.1
Summary:        A DOOM source port with graphic and modding extensions
License:        GPL-3.0-only
Group:          Amusements/Games/3D/Shoot
URL:            https://zdoom.org/

#Git-Clone:     https://github.com/zdoom/gzdoom
Source:         https://github.com/zdoom/gzdoom/archive/g%version.tar.gz
Patch2:         gzdoom-discord.patch
Patch3:         0001-Revert-Switch-to-miniz-from-zlib.patch
Patch4:         gzdoom-lzma-simd.patch
Patch5:         gzdoom-lzma.patch
Patch8:         more-32bit.patch
BuildRequires:  cmake >= 2.8.7
BuildRequires:  discord-rpc-devel
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  pkg-config
BuildRequires:  unzip
BuildRequires:  zmusic-devel
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2) >= 2.0.6
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} >= 1599
BuildRequires:  pkgconfig(clzma) >= 23.01
%else
Provides:       bundled(clzma) = 23.01
%endif
Provides:       qzdoom = 1.3.0
Provides:       zdoom = 2.8.1
Provides:       bundled(gdtoa)
Provides:       bundled(glslang) = 11.10.0
Provides:       bundled(re2c) = 0.16.0
Provides:       bundled(vulkan) = 1.2.189.1
Provides:       bundled(xbrz) = 1.8
Suggests:       freedoom

%description
GZDoom is a port (a modification) of the original Doom source code, featuring:
* an OpenGL renderer, HQnX/xBRZ rescaling, 3D floor and model support
* Truecolor software rendering, extending the classic 8-bit palette
* Heretic, Hexen and Strife game modes and support for a lot of
  additional IWADs.
* Boom and Hexen map extension support, scriptability with ACS and
  ZScript, and various modding features regarding actors and scenery.
* Demo record/playback of classic and Boom demos is not supported.

%ifarch %ix86
SSE2 is a hard requirement even on 32-bit x86.
%endif

%prep
%autosetup -n %name-g%version -p1
%if 0%{?suse_version} < 1599
# system lzma-sdk too old, use bundled copy
%patch -P 5 -R -p1
%endif
# osc/rpm always has the version identifier (only has an effect when snapshots are used via _service files)
perl -i -pe "s{<unknown version>}{%version}g" tools/updaterevision/UpdateRevision.cmake
# https://en.opensuse.org/openSUSE:Reproducible_Builds
perl -i -pe 's{__DATE__}{"'"$SOURCE_DATE_EPOCH"'"}g' src/common/platform/posix/sdl/i_main.cpp

%build
# Disable LTO, which does not like seeing handcrafted assembler
%define _lto_cflags %nil

export CXXFLAGS="$CXXFLAGS -DSHARE_DIR=\\\"%_datadir/doom\\\""
%cmake -DNO_STRIP=1 \
	-DCMAKE_SHARED_LINKER_FLAGS="" \
	-DCMAKE_EXE_LINKER_FLAGS="" -DCMAKE_MODULE_LINKER_FLAGS="" \
	-DINSTALL_DOCS_PATH="%_defaultdocdir/%name" \
	-DINSTALL_PK3_PATH="%_datadir/doom" \
	-DINSTALL_SOUNDFONT_PATH="%_datadir/doom" \
	-DDYN_OPENAL=OFF -DINSTALL_RPATH:STRING="NO"
%cmake_build

%install
%cmake_install

%post
echo "INFO: %name: The global IWAD directory is %_datadir/doom."

%files
%_bindir/%name
%_defaultdocdir/%name
%_datadir/doom/

%changelog
* Mon Jul  1 2024 Jan Engelhardt <jengelh@inai.de>
- Resolve improper __DATE__ replacement [boo#1226829]
* Fri May 17 2024 Jan Engelhardt <jengelh@inai.de>
- Delete gzdoom-waddir.patch (substitute by logic in build recipe),
  delete 0001-Revert-use-static_assert-to-make-32-bit-builds-fail.patch
  and 0001-removed-some-32bit-only-CMake-code.patch
  (merged into more-32bit.patch)
* Wed May  8 2024 Jan Engelhardt <jengelh@inai.de>
- Update more-32bit.patch to fix i586/ILP32 FTBFS.
* Tue Apr 30 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.12.2
  * Set default backend to Vulkan, if Vulkan fails go GLES not OpenGL.
  * Added a `mapinfo` console command.
  * zscript: add `final` and `sealed` as class options.
  * Always save a copy of the map in a savegame's metadata.
  * Added wall texture skewing.
  * Implemented dsda-doom's sector scrolling properties, added
    UDMF wall scrolling properties from DSDA, added friction and
    colormap related properties from DSDA, added DSDA's thrust
    properties for UDMF, and added per-sector sky UDMF
    properties.
  * Allow defining zero gravity through MAPINFO
  * Added rudimentary support for DSDA's COMPLVL lump.
  * Added actor flag +BILLBOARDFACECAMERA.
  * Added `sv_pistolstart` server flag.
- Add gzdoom-lzma-simd.patch
* Fri Oct 27 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.11.3
  * Several new languages: Danish, Norwegian, Swedish and Turkish.
  * Cleanup of Doom's and Chex Quest's small font to use proper
    character heights for international support.
  * Extended all fonts to be capable of handling all European
    languages which are in common use.
  * DSDHacked support.
  * WebP and QOI support for textures.
  * Sanitized the light mode selection to make it a first class
    mapping feature by separating map dependent light mode setup
    from performance related user preferences for the default
    setting.
  * Lots of new ZScript features.
- Delete gzdoom-vulkan.patch, gcc13.diff
- Add more-32bit.patch, 0001-Revert-Switch-to-miniz-from-zlib.patch
* Thu Mar 30 2023 Jan Engelhardt <jengelh@inai.de>
- Add gcc13.diff
* Tue Feb  7 2023 Jan Engelhardt <jengelh@inai.de>
- Update gzdoom-vulkan.patch for glslang 12
* Sun Dec  4 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.10.0
  * Map<K,V> and MapIterator<K,V> for ZScript
  * Quaternion support for model rotations
  * Improved IQM support
- Delete 0001-build-unbreak-compilation-on-Linux.patch (merged)
* Sun Nov  6 2022 Jan Engelhardt <jengelh@inai.de>
- Update description for the removal of SoftPoly
* Sat Nov  5 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.9.0
  * IQM bone model support
  * Textured particles
  * The SoftPoly renderer was removed
- Delete gzdoom-sdlbug.patch (obsolete),
  0001-fix-gzdoom.pk3-not-found-error.patch (merged)
- Add 0001-build-unbreak-compilation-on-Linux.patch,
  0001-removed-some-32bit-only-CMake-code.patch
* Mon Oct 24 2022 Jan Engelhardt <jengelh@inai.de>
- Update gzdoom-vulkan.patch for glslang-11.12.
* Sun Jul 24 2022 Jan Engelhardt <jengelh@inai.de>
- Replace 0001-Revert-load-the-hex-font-as-early-as-possible.patch
  by better fix, 0001-fix-gzdoom.pk3-not-found-error.patch .
- Drop gzdoom-asmjit.patch (no longer needed; the linkage error
  it used to fix seems just gone)
* Sun Jul 10 2022 Jan Engelhardt <jengelh@inai.de>
- Disable rpath
* Tue Jul  5 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.8.2
  * add a few maps to the rebuildnodes compatibility block
* Sun Jun 26 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.8.1
  * Bugfix for software mode mirrors not working
  * Feature: Add +ONLYVISIBLEINMIRRORS and +INVISIBLEINMIRRORS
    actor flags. The former makes the actor only visible in
    reflections, while the latter makes the actor not cast
    reflections in mirrors.
- Drop 0001-Resolve-build-failure-on-i686-linux.patch (merged)
- Add 0001-Revert-use-static_assert-to-make-32-bit-builds-fail.patch
* Thu Jun 23 2022 Jan Engelhardt <jengelh@inai.de>
- Add 0001-Revert-load-the-hex-font-as-early-as-possible.patch
* Mon Jun  6 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.8.0
  * Added Raze-style HUD scaling. Not exposed in the menu yet,
    Set hud_oldscale to 0 and use shift with the screen resize
    keys to scale the status bar.
  * Handle the start/endoom screens with the ingame renderer.
    They are now present on all platforms and use the full screen
    size of the game.
  * Many MBF21 fixes.
  * Added the cutscene system from Raze.
- Add gzdoom-discord.patch
- Add 0001-Resolve-build-failure-on-i686-linux.patch
* Sat Apr 23 2022 Jan Engelhardt <jengelh@inai.de>
- Reenable use of system vulkan libraries on Tumbleweed.
* Fri Apr 15 2022 Cristian Rodríguez <crrodriguez@opensuse.org>
- Drop unused nasm from buildrequires.
* Wed Oct 20 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.7.1
  * Allow map markers to scale relative to automap zoom.
  * Add cvars to control automap line alpha and thickness.
  * Resolved a VM abort upon morphing while the tome of power is
    active.
- Remove 0001-gles-look-for-libGLESv2.so.2.patch (merged)
* Wed Sep 22 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.7.0
  * GLES2 backend
  * Widescreen graphics for Strife
  * MBF21 support (beta)
  * DEHEXTRA works properly now
  * Various enhancements and fixes for ZScript
- Add 0001-gles-look-for-libGLESv2.so.2.patch
* Wed Jul 28 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.6.1
  * Bug fixes, and widepix updates
* Sat May 22 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.6
  * Widescreen graphics for Heretic and Hexen
  * Sprite shadows like in the Build engine. Both in software and
    hardware renderer.
  * 16 bit channel PNG files can be read.
  * DEHEXTRA working properly now.
  * Various enhancements and fixes for ZScript.
* Thu Mar  4 2021 Jan Engelhardt <jengelh@inai.de>
- Add 0001-fixed-zipdir-inability-to-update-empty-zip-file.patch
- Update to release 4.5.0
  * For all of Doom's fullscreen images, there's now widescreen
    versions provided.
  * A simplified options menu is now available for quick setup of
    the important settings.
  * New keybindings presets. Users can now choose between the
    classic layout and a WASD-based one.
  * Menu and intermission screen now scale to the original
    Doom.exe's layout by default.
  * Major additions to the menu system - animated menu
    transitions, image slideshows and fixed size menus can now be
    created.
  * The console now uses the border flat as default background
    instead of the titlepic.
  * It is now possible to fully quit the fullscreen console and
    get back to the title loop.
  * Interpolate positions and angles in the automap for smoother
    appearance.
  * Added $PitchSet for SNDINFO.
  * Allow indirections in the string table by prefixing the
    language string with '$$' the remaining text is interpreted
    as another string label to resolve.
  * Optimization of the patch texture checker - do not read in
    the entire file if checking the initial header is sufficient
    for rejecting it. This can speed up loading of large mods
    quite significantly.
  * OPUS support (via libsndfile)
- Drop gzdoom-spirv.patch (merged)
* Tue Sep 15 2020 Jan Engelhardt <jengelh@inai.de>
- Drop Recommends for music backends
  (this has moved to zmusic.spec)
- Demote Recommends to Suggests
* Wed Jun 17 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.4.2
  * Made the new "Build" light mode operational
* Fri Jun 12 2020 Jan Engelhardt <jengelh@inai.de>
- Add gzdoom-sdlbug.patch.
* Thu Jun 11 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.4.1
  * Heretic's "bag of holding" had incorrectly given mace capacity.
  * Mapped "Smooth mouse" back to the "m_filter" CVAR, and
    removed the "smooth_mouse" CVAR.
  * Fixed crash with texture upscaling in the truecolor software
    renderer.
  * Fixed crash rendering 3D floors without ceiling or floor
    textures in software.
* Sun Jun  7 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.4.0
  * Heretic's "bag of holding" had incorrectly given mace ammo.
  * Added per pixel lighting for decals.
  * Added a compatibility option for a bad teleporter in the
    final map of Strife.
  * Add a cvar to control weapon bobbing while firing.
  * Fixed crash on maps with out of range sidedef and sector
    numbers.
  * Fixed missing sound for Polyobj_MoveTo.
  * Attenuated lights for Strife.
  * Added MTF_NOCOUNT to spawn flags.
- Drop gzdoom-system-gme.patch (moved to zmusic.spec),
  gzdoom-dl.patch (unnecessary). Add gzdoom-spirv.patch.
* Wed Jan 29 2020 Michael Scafidi <raptir@gmail.com>
- Update to release 4.3.3
  * fixed resetting of music volume after closing dialogue
  * exposed Level.MusicVolume to ZScript
  * fixed calling a function on string CVar
  * added ability to filter VM disassembly dump
  * add check for unity version of Nerve.wad
  * infrastructure in place in case Nerve.wad changes again, this
    can be extended.
  * customized invulnerability colormap does not interfere with
    Powerup.ColorMap.
  * precache a few sounds being referenced in common game code.
  * define misc/secret for Hexen, too. By now there are some mods
    defining secrets for the game so this sound should be present
    there.
  * Implement special colormap support for softpoly
  * Softpoly: Fix broken fixed camera light for walls
  * make nosave standalone CVar flag, alongside server and user
  * implemented screenshots in softpoly backend
* Sun Jan 19 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.3.2
  * Added ML_NOSKYWALLS and ML_DRAWFULLHEIGHT
  * Added support for new Bethesda.Net Unity Edition WADs.
* Sat Jan 11 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.3.1
  * New softpoly backend for the hardware renderer.
  * Advanced texture colorization options.
  * Scripted map postprocessor.
  * Dictionary class for ZScript.
  * Add PSPF_PLAYERTRANSLATED flag (makes a PSprite layer
    translated to the user's color).
  * Support for MIDI on Linux via ALSA sequencer.
* Tue Dec 17 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.2.4
  * This is a bugfix release without new features. The notable
    highlight is that this fixes translucent objects in the
    software renderer.
- Add gzdoom-system-gme.patch, gzdoom-dl.patch
* Tue Oct  1 2019 Jan Engelhardt <jengelh@inai.de>
- Add gzdoom-asmjit.patch.
- Enable SSE/SSE2.
* Fri Sep 13 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.2.1
  * Level compatibility additions for Scythe 2 and Hell Revealed.
  * Add current, max and average velocity as stat.
  * Let Hexen Cleric and Mage use unique health chains.
  * Allow custom status bars to override notification and
    centered message display.
  * Improve crosshair health color to be more informative.
  * Added obituary fallbacks for actors that do not have
    any defined.
- Remove fl2.patch (merged)
* Fri Aug 23 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 4.2.0
  * The survey code has been re-enabled for this version: it sends
    basic info about the operating system but no private data:
    the number of CPU cores, the graphics card, and supported
    OpenGL/Vulkan versions.
  * Restored original vanilla behavior of Lost Souls' charging
    attack.
  * Exposed Append() method to ZScript dynamic array
  * Fixed an inconsistency with missiles bouncing off actors.
  * Added A_SoundPitch and an optional pitch parameter to
    A_PlaySound and S_Sound.
  * Attachable dynamic lights with ZScript or DECORATE.
- Drop _service and gzdoom-wadsrc-extra.patch,
  both unused since 4.1.3.
* Fri Aug 23 2019 Jan Engelhardt <jengelh@inai.de>
- Turn off LTO, it is broken. [boo#1142267]
* Sun Jun  9 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 4.1.3
  * bug fixes for both zscript and vulkan (the vulkan renderer is
    pretty much complete at this point)
  * added native double round(double) function
  * added a crosshair on/off toggle
  * cl_blockcheats 2 blocks cheats without showing any messages,
    useful for streamers who happen to be mappers/modders/etc
- Update to new upstream release 4.1.0
  * workaround buggy preprocessor in old AMD OpenGL drivers
  * fix bloom pass regression
  * fixed scale calculations for option menus.
  * implement custom post process shaders for vulkan backend
  * improve error handling during vulkan initialization
  * fixed inverted logic for displaying the generic log in Strife.
- Remove patch:
  * gzdoom-staticlibs.patch (fixed by upstream)
- Update patch:
  * gzdoom-vulkan.patch
* Mon Apr  8 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 4.0.0
  * Experimental Vulkan renderer (via "+vid_backend 0" console
    option)
  * Scaling has been changed. GZDoom now runs at a minimum of
    640x400. An extra mode (960x600) has been added to replace the
    lost 320x200 one.
  * Added "cl_blockcheats" - useful for people who use debugging
    keys, allows a user to consciously turn off cheats without
    affecting the serveradd "cl_blockcheats" - useful for people
    who use debugging keys, allows a user to consciously turn off
    cheats without affecting the server
  * "wait" console commands no longer execute inside the level,
    and can run during intermissions and outside the game.
- Folded gzdoom-asmjit.patch into gzdoom-staticlibs.patch.
- Added gzdoom-vulkan.patch.
* Wed Jan 23 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 3.7.2
  * The resolution selector now sets to auto detected resolution at
    startup, no longer uses entries from the config file.
  * Committing a scaling change for fullscreen sets scaling to 1.0
    to guarantee the selected number of pixels are actually used.
  * For details, see https://forum.zdoom.org/viewtopic.php?t=63346
* Thu Jan  3 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 3.7.1
  * Expand UDMF and ZScript API for side's own additive colors
  * Added NOFRICTION and NOFRICTIONBOUNCE actor flags
  * Added an AMD64 JIT for DECORATE and ZScript
  * Lights are now referenced by sections rather than surface, to
    speed up light linking. This should allow a dynamically-lit
    plasma bolt to pass over a 3D bridge in Frozen Time without
    turning the game into a slide show.
  * Add shader cache for Intel GPUs which should result in faster
    startups.
- Add gzdoom-asmjit.patch
* Wed Nov 14 2018 Jan Engelhardt <jengelh@inai.de>
- Update description
* Tue Oct 16 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 3.6.0
  * Add OBJ model support
  * Add HITOWNER flag, when set, allows a projectile to collide
    with its shooter.
  * Enabled the linear shadowmap filter.
  * Added 5x and 6x upscaling with xBRZ
  * Exports various resurrection-related functions to ZScript.
- Update to new upstream release 3.5.1
  * Added post processing support to the software renderer and
    softpoly.
- Add fl2.patch
* Sun Aug  5 2018 mardnh@gmx.de
- Update to version 3.5.0
  * (modern branch only) Fullscreen is now borderless window (which,
    technically, it always has been, anyhow). Removed hacks which
    changed the desktop resolution in order to simulate exclusive
    fullscreen because they were a constant stability concern.
  * (modern branch only) fixed a performance regression with the
    software renderer, introduced by the recent changes to the video
    backend in 3.4.
  * Save item statistics - Items are now saved into save games and
    are displayed on the statfile
  * Upgrade libADLMIDI and libOPNMIDI
  * Large number of MinGW fixes
  * add tags for all Doom and Heretic monsters for mods that reveal
    monster names
  * various compatibility fixes for old maps and mods
  * fixed titlepic animation
  * Custom hardware shaders now can use custom texture units
  * default to "fullscreen" display
  * fixed a potential exploit with malformed WAD files.
- Update to version 3.4.1
  * fixed: redirect script access to the compatflags CVARs to their
    internal shadow variables. This is needed so that MAPINFO settings
    for these flags don't get ignored.
  * fixed: flag CVars in ZScript referenced wrong addresses
  * fixed: ZScript used the wrong variable for compatflags2.
  * fixed: remove ARM specific gl_es definition since it's not even
    really much different from the main line definition, anyhow
  * fixed generation of brightmaps for sprites. This forgot to take
    the added empty border for filtering improvement into account.
  * fixed ADynamicLight's shadowmap index must be reset when loading
    a savegame.
  * fixed portal restoration on revisiting level in hub.
  * Added function to FLevelLocals to test if map is being reentered.
  * fixed crash with GL 3.x and fixed colormap active.
- Update to version 3.4.0
  * enable #include support in modeldef files
  * removed DirectDraw and Direct3D backends, removed unaccerated SDL
    framebuffer backend
  * reorganization of 2D and 3D rendering code in preparation for Vulkan
    in the future, performance improvements on newer hardware
  * CVAR that handles it is now 'vid_rendermode' - vid_renderer,
    swtruecolor, and r_polyrender have been removed and combined into
    new CVAR
  * added a 'lightsizefactor' command to gldefs.
  * allow animated title pics.
  * Add support for Unreal Engine 1 vertex mesh format.
  * added LevelLocals vec2/3Offset(Z) functions for portal-aware
    offsetting without needing actors
  * Add "OnGiveSecret" virtual function on Actor for customizing behavior
    of secret finding.
  * BLOCKASPLAYER flag: treat non-player actors as blockable by
    "block players" lines
  * added 'revealed on automap' linedef flag, UDMF only
  * added forced automap style to linedef, UDMF only
  * Added startup song definition for custom IWADs
  * This release contains a major render optimization for highly detailed
    maps that may give a +20%% performance improvement on Intel and AMD
    hardware (less on NVidia because the driver has far less overhead that
    could be optimized away.)
- Update to version 3.3.2
  * Fixed detection of .ipk7 custom IWADs
  * Restored vanilla behavior of lightning for original Hexen
  * Added loading of ZSDF lumps by full paths
  * Disabled the survey code
  * Exported P_ActivateLine() to ZScript along with constants for
    activation type
  * Increased size of the savegame comment area.
- Update to version 3.3.1
  * Better handling of defaults with some ZScript/DECORATE functions
  * Many bug fixes since 3.3.0
- Update to version 3.3.0
  ZScript & Mapping Highlights
  * Added dynamic spot lights, configurable in the UDMF map format
  * Exported GetChecksum() function as part of FLevelLocals in ZScript
  * Mod-defined aliases no longer permanently change CVARs
  * Added FriendlySeeBlocks actor property that allows a modder to expand
    the maximum radius that a friendly monster can see enemies. It's
    accessible from both ZScript/DECORATE and UDMF
  * Custom submenus are no longer removed from altered protected menu
  * Exported S_GetMSLength() function to ZScript
  * Added GetRadiusDamage() function. It returns the raw calculated
    explosion damage falloff by distance only
  * Added Screen.getViewWindow() function
  * Exported Trace() interface to ZScript
  * Added TeleportSpecial() as an alias for Teleport() in ZScript to
    deconflict from Actor.Teleport() function
  * Added Distance2DSquared() and Distance3DSquared() functions
  * Fixed skip_super application for ZScript
  * Split off the interface part of DHUDMessage
  * Exported sector effect pointers
  * Fixed missing pointer assignment on Lighting effect creation
  * Made left button down event available to UI event handler
  * Exported Inventory.AltHUDIcon field to ZScript
  * Added WorldLinePreActivated to override line activation
  * Added DI_MIRROR flag to statusbar image drawing, useful for rearview
    mirrors
  * Enabled string and float user_ properties in UDMF things
  Other Highlights
  * Added in-game reverb editor using the menu system
  * Improved French translations
  * Fixed 'precise' rendering in OpenGL
  * Added new Materials Shader system to allow textures to show new
    properties such as glossiness and specularity, affected by dynamic
    lights, or with PBR, reflecting their direct surroundings
  * Added new rocket smoke sprites by Talon1024
  * Embedded Timidity++ into GZDoom directly
  * Added light definition for megasphere
  * Fixed midtex nowrap clipping bug when 3d floors are in view
    (Software Renderer)
  * Improved profilethinkers in various ways
  * Added variables am_unexploredsecretcolor and am_ovunexploredsecretcolor
    to mark undiscovered secrets differentl
- Drop patch (Upstream updated to 18.05):
  * 0001-Update-LZMA-SDK-to-version-17.01.patch
- Rebase patch:
  * gzdoom-lzma.patch
* Mon Jan  8 2018 jengelh@inai.de
- Update to new upstream 3.2.5
  * Implemented 'i_soundinbackground' to continue playing sounds
    and music while in background.
  * OpenGL rendering now continues even when losing focus if not
    running fullscreen.
  * Added 'playerrespawn' skill flag to allow gameplay mods to
    retroactively enable player respawns in single player on
    all maps.
  * Improved Advanced Sound Options menu - added option for
    FluidSynth chorus, removed fractional part from FluidSynth
    voices option.
  * Fixed applying of Doom 64 lighting to horizon portals.
  * Particles are now interpolated.
- Use system lzma-sdk
- Add 0001-Update-LZMA-SDK-to-version-17.01.patch,
  gzdoom-lzma.patch, gzdoom-wadsrc-extra.patch
* Tue Jan  2 2018 jengelh@inai.de
- Remove zdoom from the specfile (which had built both zdoom and
  gzdoom due to their similarity) and rename to gzdoom.spec.
- Update to new upstream release 3.2.4
  * Recognition for the HacX 2.0 IWAD
  * Recognition for the modified Doom 1/2/U IWADs and the "No Rest
    for the Living" expansion pack shipped in the Doom3 BFG Edition.
  * New GL3 node format for complex UDMF maps which need fractional
    precision on node splitters.
  * The ZScript scripting language has been added.
  * A new 32-bit software renderer has been added.
    The classic 8-bit renderer remains available.
- Add gzdoom-waddir.patch, gzdoom-staticlibs.patch.
* Sun Mar 24 2013 jengelh@inai.de
- Standardize on /usr/share/doom for IWADs.
- Per-user configuration is to be moved to ~/.config/zdoom
  (XDG environment variables are not respected, though),
  ~/.config/gzdoom and ~/.config/zandronum for the different
  game engines respectively.
* Thu Mar 21 2013 jengelh@medozas.de
- Update to new upstream release zdoom-2.6.0+svn4191
  and gzdoom-1.7.01+svn1526
  * berserk indicator on alternative HUD
  * support for BFG edition IWADs
  * sound precaching through MAPINFO.
- Imported zandronum-1.0+hg3641 (formerly Skulltag)
* Tue Jul 10 2012 jengelh@inai.de
- Update to new upstream release 2.6.0 (gzdoom-1.6.0)
  * Added Hacx IWAD support.
  * Added text-format Strife conversation system with USDF and ZSDF.
  * A textured automap is now available; automap graphics are now
  externalized.
  * Rewritten menu system, which can now be defined with the MENUDEF
  lump.
  * Externalized intermissions to MAPINFO.
  * Externalized IWAD detection and gave each IWAD its own
  independent config section.
  * Added FluidSynth and GUS emulator softsynths; fixed issues with
  TiMidity++.
  * Added VOC support and enhanced MIDI playback with support for
  alternative formats such as XMI and HMI.
  * Action specials: Added Ceiling_LowerAndCrushDist and
  Thing_SetConversation. Added console command to execute specials.
  * ACS: Increased maximum script number from 999 to 32767.
  * ACS: Named scripts allow to avoid script number conflicts
  altogether.
  * ACS: Added StrCopy, CheckSight, SetActivator, SetPointer
  functions.
  * ACS: Added APROP_ScaleX/Y and APROP_Mass actor properties.
  * ACS: Added temporary dynamic strings variables with StrParam.
  * ACS: Scripts can now have up to four parameters.
  * DECORATE: Added A_CheckFlag, A_FaceMaster, A_FaceTracer,
  A_RadiusGive, A_SetMass, A_SetScale, A_Warp and A_WolfAttack...
  * DECORATE: Enhanced A_AlertMonsters, A_BFGSpray, A_Blast,
  A_CustomBulletAttack, A_FireBullets, A_GunFlash, A_PainAttack,
  A_RadiusThrust...
  * DECORATE: Added an actor pointer manipulation system with several
  new codepointers...
  * DECORATE: Added DOHARMSPECIES, DONTCORPSE, SEEINVISIBLE and
  INVENTORY.UNTOSSABLE
  * DECORATE: Increased damage type flexibility in several ways with
  DeathType and PainType.
  * DECORATE: Added customizable fléchettes.
  * DECORATE: Made accuracy and stamina accessible through DECORATE
  expressions.
  * DECORATE: Added ProjectileKickback, Inventory.RestrictedTo and
  Inventory.ForbiddenTo class-based properties.
  * DECORATE: Backported VisibleToTeam, VisibleToPlayerClass and
  weapon DropItem feature from Skulltag, and enhanced them.
  * DECORATE: Added "Fast" keyword for states and deprecated the
  unreliable FASTER and FASTMELEE flags.
  * Added a secret hint system.
  * 3D floors support.
  * FraggleScript support.
  * Voxel support.
  * SBARINFO: Ammo 1/2 capacities added to DrawNumber, support for
  color names in colored text.
  * SNDINFO: Added musicalias and attenuation.
  * Compatibility: fixed issues with Eternal Doom, Happy Time Circus,
  Phobos, vanilla compat, Boom compat, light levels higher than
  255, Heretic, Strife, MUSINFO, misnamed UDMF field.
  * Fixed loading of BMF palettes.
  * restart console command.
  * Added PALVERS lump for specifying alternate graphics to use with
  a paletted render, in case the graphics you really want to use
  look bad without true color.
  * Custom IWADs no longer need to include a COLORMAP, as ZDoom will
  generate one automatically if it is missing.
  * Fixed vertical tiling of non-power-of-two textures.
* Sat Nov 27 2010 jengelh@medozas.de
- cmake is really weird when it comes to CFLAGS.
  Pass :STRING= to make it actually use our flags.
- set RPM group for gzdoom to one that rpmlint accepts
- disable strip to make debuginfo packages work
- fix a crash caused by an uninitialized variable
* Fri Sep 10 2010 jengelh@medozas.de
- Enable building with experimental fluidsynth support
- Optimize PNGs before packing up
- Do not use FMODEx for building on non-x86
- Remove unneeded p7zip build dependency (repacked + patched
  .tar.xz is used since a while)
- Update to ZDoom 2.5.0
  * Obsoleted zdoom-binutils.diff
- Update to GZDoom 1.5.02
* Fri Jul 30 2010 jengelh@medozas.de
- Add patch to workaround compile issues with binutils 2.20.0
* Wed Jul 28 2010 jengelh@medozas.de
- Split up zdoom package into its components
- zdoom, gzdoom, zdoom-devel
